@@ -9,7 +9,7 @@ import Distribution.Simple.Configure (configCompilerAux)
 import Distribution.PackageDescription (PackageDescription(..))
 import Distribution.Simple.InstallDirs
                             (InstallDirs(..))
-import Distribution.Simple.Program 
+import Distribution.Simple.Program
                             (Program(..),ConfiguredProgram(..),ProgramConfiguration(..),
                              ProgramLocation(..),simpleProgram,lookupProgram,
                              rawSystemProgramConf)
@@ -28,15 +28,14 @@ import System.IO.Error (try)
 import System.Process (runInteractiveProcess,waitForProcess)
 import System.Directory
 import System.Info (os)
-  
 
 lhs2tex = "lhs2TeX"
 minPolytableVersion = [0,8,2]
 shortversion = show (numversion `div` 100) ++ "." ++ show (numversion `mod` 100)
 version = shortversion ++ if ispre then "pre" ++ show pre else ""
-numversion = 115
+numversion = 117
 ispre = False
-pre = 1
+pre = 2
 
 main = defaultMainWithHooks lhs2texHooks
 
@@ -45,7 +44,8 @@ sep =  if isWindows then ";" else ":"
 lhs2texBuildInfoFile :: FilePath
 lhs2texBuildInfoFile = "." `joinFileName` ".setup-lhs2tex-config"
 
-generatedFiles = ["Version.lhs","lhs2TeX.1",
+generatedFiles = ["src" `joinFileName` "Version.lhs",
+                  "lhs2TeX.1",
                   "doc" `joinFileName` "InteractiveHugs.lhs",
                   "doc" `joinFileName` "InteractivePre.lhs"]
 
@@ -168,7 +168,7 @@ lhs2texBuildDocumentation a (BuildFlags { buildVerbosity = vf }) pd lbi =
                          callLhs2tex v lbi ["--" ++ incToStyle inc , "-Pdoc" ++ sep, lhs2texDir `joinFileName` snippet]
                                            (lhs2texDocDir `joinFileName` s ++ ".tex")
                 ) snippets
-        callLhs2tex v lbi ["--poly" , "-Pdoc" ++ sep, "doc" `joinFileName` "Guide2.lhs"]
+        callLhs2tex v lbi ["--poly" , "-Pdoc" ++ sep, "-Psrc" ++ sep, "doc" `joinFileName` "Guide2.lhs"]
                           (lhs2texDocDir `joinFileName` "Guide2.tex")
         copyFileVerbose v ("polytable" `joinFileName` "polytable.sty") (lhs2texDocDir `joinFileName` "polytable.sty")
         copyFileVerbose v ("polytable" `joinFileName` "lazylist.sty")  (lhs2texDocDir `joinFileName` "lazylist.sty")
@@ -191,11 +191,11 @@ lhs2texPostCopy a (CopyFlags { copyDest = cdf, copyVerbosity = vf }) pd lbi =
         createDirectoryIfMissing True dataPref
         let lhs2texDir = buildDir lbi `joinFileName` lhs2tex
         -- lhs2TeX.{fmt,sty}
-        mapM_ (\f -> copyFileVerbose v (lhs2texDir `joinFileName` f) (dataPref `joinFileName` f))
+        mapM_ (\f -> installOrdinaryFile v (lhs2texDir `joinFileName` f) (dataPref `joinFileName` f))
               ["lhs2TeX.fmt","lhs2TeX.sty"]
         -- lhs2TeX library
         fmts <- fmap (filter (".fmt" `isSuffixOf`)) (getDirectoryContents "Library")
-        mapM_ (\f -> copyFileVerbose v ("Library" `joinFileName` f) (dataPref `joinFileName` f))
+        mapM_ (\f -> installOrdinaryFile v ("Library" `joinFileName` f) (dataPref `joinFileName` f))
               fmts
         -- documentation difficult due to lack of docdir
         let lhs2texDocDir = lhs2texDir `joinFileName` "doc"
@@ -206,10 +206,10 @@ lhs2texPostCopy a (CopyFlags { copyDest = cdf, copyVerbosity = vf }) pd lbi =
                        then dataPref `joinFileName` "Documentation"
                        else datadir (absoluteInstallDirs pd lbi cd) `joinFileName` ".." `joinFileName` "man" `joinFileName` "man1"
         createDirectoryIfMissing True docDir
-        copyFileVerbose v (lhs2texDocDir `joinFileName` "Guide2.pdf") (docDir `joinFileName` "Guide2.pdf")
+        installOrdinaryFile v (lhs2texDocDir `joinFileName` "Guide2.pdf") (docDir `joinFileName` "Guide2.pdf")
         when (not isWindows) $
           do createDirectoryIfMissing True manDir
-             copyFileVerbose v ("lhs2TeX.1") (manDir `joinFileName` "lhs2TeX.1")
+             installOrdinaryFile v ("lhs2TeX.1") (manDir `joinFileName` "lhs2TeX.1")
         -- polytable
         case (installPolyTable ebi) of
           Just texmf -> do  let texmfDir = texmf
@@ -218,8 +218,8 @@ lhs2texPostCopy a (CopyFlags { copyDest = cdf, copyVerbosity = vf }) pd lbi =
                             createDirectoryIfMissing True ptDir
                             stys <- fmap (filter (".sty" `isSuffixOf`))
                                          (getDirectoryContents "polytable")
-                            mapM_ (\f -> copyFileVerbose v ("polytable" `joinFileName` f)
-                                                           (ptDir `joinFileName` f))
+                            mapM_ (\f -> installOrdinaryFile v ("polytable" `joinFileName` f)
+                                                               (ptDir `joinFileName` f))
                                   stys
           Nothing    -> return ()
 
@@ -291,9 +291,9 @@ getProgram progName programConf =
              do  let mProg = lookupProgram (simpleProgram progName) programConf
                  case mProg of
                    Just (ConfiguredProgram { programLocation = UserSpecified p,
-                                             programArgs = args })  -> return (p,args)
+                                             programDefaultArgs = args })  -> return (p,args)
                    Just (ConfiguredProgram { programLocation = FoundOnSystem p,
-                                             programArgs = args })  -> return (p,args)
+                                             programDefaultArgs = args })  -> return (p,args)
                    _ -> (die (progName ++ " command not found"))
 
 -- | Run a command in a specific environment and return the output and errors.
